#ifndef _ELM_INTERFACE_ATSPI_TEXT_EDITABLE_EO_H_
#define _ELM_INTERFACE_ATSPI_TEXT_EDITABLE_EO_H_

#ifndef _ELM_INTERFACE_ATSPI_TEXT_EDITABLE_EO_CLASS_TYPE
#define _ELM_INTERFACE_ATSPI_TEXT_EDITABLE_EO_CLASS_TYPE

typedef Eo Elm_Interface_Atspi_Text_Editable;

#endif

#ifndef _ELM_INTERFACE_ATSPI_TEXT_EDITABLE_EO_TYPES
#define _ELM_INTERFACE_ATSPI_TEXT_EDITABLE_EO_TYPES


#endif
#define ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE elm_interface_atspi_text_editable_interface_get()

EWAPI const Eo_Class *elm_interface_atspi_text_editable_interface_get(void);

#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_PROTECTED
EOAPI Eina_Bool elm_interface_atspi_text_editable_content_set(Eo *obj, const char *string);
#endif

#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_PROTECTED
EOAPI Eina_Bool elm_interface_atspi_text_editable_insert(Eo *obj, const char *string, int position);
#endif

#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_PROTECTED
EOAPI Eina_Bool elm_interface_atspi_text_editable_copy(Eo *obj, int start, int end);
#endif

#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_PROTECTED
EOAPI Eina_Bool elm_interface_atspi_text_editable_cut(Eo *obj, int start, int end);
#endif

#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_PROTECTED
EOAPI Eina_Bool elm_interface_atspi_text_editable_delete(Eo *obj, int start, int end);
#endif

#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_PROTECTED
EOAPI Eina_Bool elm_interface_atspi_text_editable_paste(Eo *obj, int position);
#endif


#endif
