namespace elm { namespace interface { namespace atspi { namespace text { 
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::content_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type string) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_content_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(string));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::insert( ::efl::eolian::in_traits< ::efl::eina::string_view>::type string,  ::efl::eolian::in_traits<int>::type position) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_insert(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(string)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(position));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::copy( ::efl::eolian::in_traits<int>::type start,  ::efl::eolian::in_traits<int>::type end) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_copy(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::cut( ::efl::eolian::in_traits<int>::type start,  ::efl::eolian::in_traits<int>::type end) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_cut(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::cxx_delete( ::efl::eolian::in_traits<int>::type start,  ::efl::eolian::in_traits<int>::type end) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_delete(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::paste( ::efl::eolian::in_traits<int>::type position) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_paste(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(position));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
} } } } 
namespace eo_cxx {
namespace elm { namespace interface { namespace atspi { namespace text { 
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::content_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type string) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_content_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(string));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::insert( ::efl::eolian::in_traits< ::efl::eina::string_view>::type string,  ::efl::eolian::in_traits<int>::type position) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_insert(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(string)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(position));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::copy( ::efl::eolian::in_traits<int>::type start,  ::efl::eolian::in_traits<int>::type end) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_copy(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::cut( ::efl::eolian::in_traits<int>::type start,  ::efl::eolian::in_traits<int>::type end) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_cut(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::cxx_delete( ::efl::eolian::in_traits<int>::type start,  ::efl::eolian::in_traits<int>::type end) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_delete(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_EDITABLE_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Editable::paste( ::efl::eolian::in_traits<int>::type position) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_editable_paste(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(position));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
inline elm::interface::atspi::text::Editable::operator ::elm::interface::atspi::text::Editable() const { return *static_cast< ::elm::interface::atspi::text::Editable const*>(static_cast<void const*>(this)); }
inline elm::interface::atspi::text::Editable::operator ::elm::interface::atspi::text::Editable&() { return *static_cast< ::elm::interface::atspi::text::Editable*>(static_cast<void*>(this)); }
inline elm::interface::atspi::text::Editable::operator ::elm::interface::atspi::text::Editable const&() const { return *static_cast< ::elm::interface::atspi::text::Editable const*>(static_cast<void const*>(this)); }
} } } } }

